basic tools to create NPL model for Disaster Response project. You can find the repository for the project [here](https://github.com/6one2/DisasterResponsePipeline_Figure8)

# __Description__
This package consists of 1 main module `utils`:
 - `tokenize`: custom tokenizer based on nltk
 - `FeatureCount`: transformer for added features


# __Installation__
`pip install herokutils`
